@@ -1,4 +1,4 @@
-extensions = ['natbib']
+extensions = ['test.natbib']
 exclude_patterns = ['_build']
 natbib = {
     'file': 'test.bib',
