@@ -1,18 +1,19 @@
 from typing import Set
 
-import common
+from test.common import \
+    html_citations, html_citation_refs, html_footnotes, html_footnote_refs
 import pytest
 import re
 
 
 def citation_refs(output) -> Set[str]:
     return {match.group('label')
-            for match in common.html_citation_refs().finditer(output)}
+            for match in html_citation_refs().finditer(output)}
 
 
 def citations(output) -> Set[str]:
     return {match.group('label')
-            for match in common.html_citations().finditer(output)}
+            for match in html_citations().finditer(output)}
 
 
 @pytest.mark.sphinx('html', testroot='bibliography_empty', freshenv=True)
@@ -59,13 +60,13 @@ def test_bibliography_style_label_1(app, warning) -> None:
     output = (app.outdir / "index.html").read_text()
     # the custom style uses keys as labels
     # citations
-    assert len(common.html_citations(
+    assert len(html_citations(
         label='myfancybibtexkey').findall(output)) == 1
-    assert len(common.html_citations(
+    assert len(html_citations(
         label='myotherfancybibtexkey').findall(output)) == 1
-    assert len(common.html_citation_refs(
+    assert len(html_citation_refs(
         label='myfancybibtexkey').findall(output)) == 1
-    assert len(common.html_citation_refs(
+    assert len(html_citation_refs(
         label='myotherfancybibtexkey').findall(output)) == 1
 
 
@@ -74,8 +75,8 @@ def test_bibliography_style_label_2(app, warning) -> None:
     app.build()
     assert not warning.getvalue()
     output = (app.outdir / "index.html").read_text()
-    assert len(common.html_citation_refs(label='APAa').findall(output)) == 1
-    assert len(common.html_citation_refs(label='APAb').findall(output)) == 1
+    assert len(html_citation_refs(label='APAa').findall(output)) == 1
+    assert len(html_citation_refs(label='APAb').findall(output)) == 1
 
 
 @pytest.mark.sphinx('html', testroot='bibliography_style_nowebref')
@@ -137,8 +138,8 @@ def test_bibliography_label_prefix_2(app, warning) -> None:
     assert sum_refs <= citation_refs(output3)
     assert sum_cites == citations(output3)
     # check citation reference from summary to doc1
-    match1 = common.html_citations(label='AFM12').search(output1)
-    match3 = common.html_citation_refs(label='AFM12').search(output3)
+    match1 = html_citations(label='AFM12').search(output1)
+    match3 = html_citation_refs(label='AFM12').search(output3)
     assert match1
     assert match3
     assert match1.group('id_') == match3.group('refid')
@@ -163,15 +164,18 @@ def test_bibliography_multi_foot(app, warning) -> None:
     assert not warning.getvalue()
     output = (app.outdir / "index.html").read_text(encoding='utf-8')
     assert output.count('<p class="rubric"') == 3
-    assert len(re.findall('id="mandel"', output)) == 1
-    assert len(re.findall('id="evensen"', output)) == 1
-    assert len(re.findall('id="lorenc"', output)) == 1
     assert len(re.findall(
-        'class="footnote-reference brackets" href="#mandel"', output)) == 2
+        html_footnotes(id_="footcite-2009-mandel"), output)) == 1
     assert len(re.findall(
-        'class="footnote-reference brackets" href="#evensen"', output)) == 1
+        html_footnotes(id_="footcite-2003-evensen"), output)) == 1
     assert len(re.findall(
-        'class="footnote-reference brackets" href="#lorenc"', output)) == 1
+        html_footnotes(id_="footcite-1986-lorenc"), output)) == 1
+    assert len(re.findall(
+        html_footnote_refs(refid='footcite-2009-mandel'), output)) == 2
+    assert len(re.findall(
+        html_footnote_refs(refid='footcite-2003-evensen'), output)) == 1
+    assert len(re.findall(
+        html_footnote_refs(refid='footcite-1986-lorenc'), output)) == 1
 
 
 @pytest.mark.sphinx('html', testroot='bibliography_missing_field')
@@ -199,3 +203,55 @@ def test_bibliography_content(app, warning) -> None:
 def test_bibliography_bad_key(app, warning) -> None:
     app.build()
     assert 'could not find bibtex key "badkey"' in warning.getvalue()
+
+
+def url(link: str) -> str:
+    return f'<a class="reference external" href="{link}">{link}</a>'
+
+
+@pytest.mark.sphinx('html', testroot='bibliography_url')
+def test_bibliography_url(app, warning) -> None:
+    app.build()
+    assert not warning.getvalue()
+    output = (app.outdir / "index.html").read_text(encoding='utf-8')
+    match1 = html_citations(label='Een').search(output)
+    match2 = html_citations(label='Twe').search(output)
+    match3 = html_citations(label='Dri').search(output)
+    match4 = html_citations(label='Vie').search(output)
+    assert match1 is not None
+    assert match2 is not None
+    assert match3 is not None
+    assert match4 is not None
+    assert url('https://github.com/') in match1.group('text')
+    assert 'aaa' + url('https://google.com/') + 'bbb' in match2.group('text')
+    assert url('https://youtube.com/') in match3.group('text')
+    assert 'URL: ' + url('https://wikipedia.org/') in match4.group('text')
+
+
+@pytest.mark.sphinx('html', testroot='bibliography_custom_ids')
+def test_bibliography_custom_ids(app, warning) -> None:
+    app.build()
+    assert not warning.getvalue()
+    output = (app.outdir / "index.html").read_text(encoding='utf-8')
+    assert '<p id="bibliography-id-1">' in output
+    assert '<p id="bibliography-id-2">' in output
+    assert '<p id="footbibliography-id-1">' in output
+    assert '<p id="footbibliography-id-2">' in output
+    match1 = html_citations(text='.*Evensen.*').search(output)
+    match2 = html_citations(text='.*Mandel.*').search(output)
+    match3 = html_citations(text='.*Lorenc.*').search(output)
+    assert match1 is not None
+    assert match2 is not None
+    assert match3 is not None
+    assert match1.group('id_') == 'cite-id-1-2003-evensen'
+    assert match2.group('id_') == 'cite-id-1-2009-mandel'
+    assert match3.group('id_') == 'cite-id-2-1986-lorenc'
+    match1 = html_footnotes(text='.*Evensen.*').search(output)
+    match2 = html_footnotes(text='.*Mandel.*').search(output)
+    match3 = html_footnotes(text='.*Lorenc.*').search(output)
+    assert match1 is not None
+    assert match2 is not None
+    assert match3 is not None
+    assert match1.group('id_') == 'footcite-id-2003-evensen'
+    assert match2.group('id_') == 'footcite-id-2009-mandel'
+    assert match3.group('id_') == 'footcite-id-1986-lorenc'
