@@ -9,6 +9,6 @@ import pytest
 
 
 @pytest.mark.sphinx('html', testroot='sphinx')
-def test_sphinx(app, warning):
+def test_sphinx(app, warning) -> None:
     app.build()
     assert not warning.getvalue()
